@@ -18,3 +18,16 @@ async def test_gitlab_max_tag(get_version):
 
 async def test_gitlab_max_tag_with_ignored_tags(get_version):
     assert await get_version("example", {"gitlab": "gitlab-org/gitlab-test", "use_max_tag": 1, "ignored_tags": "v1.1.0"}) == "v1.0.0"
+
+async def test_gitlab_max_tag_with_include(get_version):
+    assert await get_version("example", {
+        "gitlab": "gitlab-org/gitlab-test", "use_max_tag": 1,
+        "include_regex": r'v1\.0.*',
+    }) == "v1.0.0"
+
+async def test_gitlab_max_tag_with_ignored(get_version):
+    assert await get_version("example", {
+        "gitlab": "gitlab-org/gitlab-test", "use_max_tag": 1,
+        "ignored": "v1.1.0",
+    }) == "v1.0.0"
+
